Module claims

Module claims 

Runtime claim compiler for truth-ceiling enforcement.

Structs

CompiledRuntimeClaim
Compiled runtime claim with weakest-link ceiling and allow/deny decision.
DevelopmentLedgerUseDecision
Decision for using one event payload in a requested authority surface.
RuntimeClaimPreflight
Fail-closed decision for a proof-bearing runtime claim surface.

Enums

DevelopmentLedgerUse
Use requested for development-ledger data.
RuntimeClaimKind
Runtime claim class with a minimum authority ceiling.

Functions

compile_runtime_claim
Compile a runtime claim and decide whether it may be emitted affirmatively.
development_ledger_use_decision
Decides whether a run-event payload may be used for the requested surface.
require_runtime_claim
Return an error message when a proof-bearing claim cannot satisfy its requested authority surface.
require_runtime_claim_with_policy
Return an error when policy or proof/runtime ceilings cannot satisfy the requested authority surface.
runtime_claim_preflight
Preflight a proof-bearing runtime claim before a command emits, exports, or persists an authority-bearing result.
runtime_claim_preflight_with_policy
Preflight a proof-bearing runtime claim and include an ADR 0026 policy decision in the ceiling computation.