pub struct DevelopmentLedgerUseDecision {
pub requested_use: DevelopmentLedgerUse,
pub allowed: bool,
pub reason: String,
}Expand description
Decision for using one event payload in a requested authority surface.
Fields
requested_use: DevelopmentLedgerUseRequested use.
allowed: boolWhether this event payload may be used for that surface.
reason: StringDecision reason.