pub fn bind_keys(rl: &mut Editor<CortexHelper, DefaultHistory>)Expand description
Bind custom key sequences to the editor for interactive command selection.
pub fn bind_keys(rl: &mut Editor<CortexHelper, DefaultHistory>)Bind custom key sequences to the editor for interactive command selection.