pub fn create_mapping_progress() -> (MultiProgress, Vec<ProgressBar>)Expand description
Create a multi-step progress display for a mapping operation.
Returns the MultiProgress handle and a vector of individual progress bars.
pub fn create_mapping_progress() -> (MultiProgress, Vec<ProgressBar>)Create a multi-step progress display for a mapping operation.
Returns the MultiProgress handle and a vector of individual progress bars.