GraphQL schema generator.
Generates a GraphQL schema with types, queries, and mutations from compiled models.
Functions
- generate_
graphql - Generate a complete GraphQL schema from a compiled schema.
GraphQL schema generator.
Generates a GraphQL schema with types, queries, and mutations from compiled models.