MCP tool definition generator.
Generates MCP tool definitions scoped to a specific compiled site.
Functions
- generate_
mcp - Generate MCP tool definitions JSON from a compiled schema.
MCP tool definition generator.
Generates MCP tool definitions scoped to a specific compiled site.