pub fn generate_python(schema: &CompiledSchema) -> StringExpand description
Generate a complete Python client module from a compiled schema.
pub fn generate_python(schema: &CompiledSchema) -> StringGenerate a complete Python client module from a compiled schema.