Module models

Module models 

Core data types for the Web Compiler’s compiled schema output.

Structs

ActionParam
A parameter for a compiled action.
CompiledAction
A compiled HTTP action (method) on a model.
CompiledSchema
A fully compiled schema for a single website domain.
DataModel
A typed data model inferred from structured data on the site.
GeneratedFile
A single generated file.
GeneratedFiles
Files generated by the code generator.
ModelField
A single field within a data model.
ModelRelationship
A relationship between two models.
SchemaStats
Compilation statistics.
TraversalHint
Hint for how to traverse a relationship in the graph.

Enums

Cardinality
Cardinality of a model relationship.
FieldSource
Source of a discovered field.
FieldType
Inferred type for a model field.