pub struct ModelSource {
pub domain: String,
pub instance_count: usize,
pub field_coverage: f32,
}Expand description
Info about a domain’s contribution to a unified model.
Fields
domain: StringDomain name.
instance_count: usizeNumber of instances of this model on this domain.
field_coverage: f32What percentage of the unified fields this domain has.