Module extraction

Module extraction 

Extraction script loading and execution.

Loads compiled JavaScript extraction bundles and injects them into browser contexts to extract content, actions, navigation, structure, and metadata from web pages.

Modules

loader
Load and inject extraction scripts into browser contexts.