pub async fn run(
task: impl Into<String>,
adapter: &dyn LlmAdapter,
pack: ContextPack,
) -> Result<RunReport, RuntimeError>Expand description
Run a task through an adapter using an already-built context pack.
pub async fn run(
task: impl Into<String>,
adapter: &dyn LlmAdapter,
pack: ContextPack,
) -> Result<RunReport, RuntimeError>Run a task through an adapter using an already-built context pack.