pub async fn run_configured(
run: Run,
adapter: &dyn LlmAdapter,
) -> Result<RunReport, RuntimeError>Expand description
Run a fully configured runtime request through an adapter.
pub async fn run_configured(
run: Run,
adapter: &dyn LlmAdapter,
) -> Result<RunReport, RuntimeError>Run a fully configured runtime request through an adapter.