Module refresh

Module refresh 

REFRESH handler — re-render nodes and update the map.

Structs

RefreshRequest
Parameters for a refresh operation.
RefreshResult
Result of a refresh operation.

Functions

detect_changes
Compare old and new features to detect changes.
feature_hash
Compute a content hash for a feature vector (to detect changes).
select_nodes_to_refresh
Determine which nodes to refresh based on the request parameters.