Serialize a SiteMap to the binary CTX format.
The format ends with a 4-byte CRC32 checksum (IEEE) of all preceding bytes, allowing integrity verification on load.
Serialize a SiteMap to the binary CTX format.
The format ends with a 4-byte CRC32 checksum (IEEE) of all preceding bytes, allowing integrity verification on load.