Module manager

Module manager 

Pool manager for browser rendering contexts.

Manages a pool of browser contexts, controlling concurrency and reusing contexts when possible.

Structs

ContextHandle
Handle to a borrowed browser context from the pool.
PoolManager
Manages a pool of browser contexts with concurrency limits.