Runtime claim compiler for truth-ceiling enforcement.
Structs
- Compiled
Runtime Claim - Compiled runtime claim with weakest-link ceiling and allow/deny decision.
- Development
Ledger UseDecision - Decision for using one event payload in a requested authority surface.
- Runtime
Claim Preflight - Fail-closed decision for a proof-bearing runtime claim surface.
Enums
- Development
Ledger Use - Use requested for development-ledger data.
- Runtime
Claim Kind - Runtime claim class with a minimum authority ceiling.
Functions
- compile_
runtime_ claim - Compile a runtime claim and decide whether it may be emitted affirmatively.
- development_
ledger_ use_ decision - Decides whether a run-event payload may be used for the requested surface.
- require_
runtime_ claim - Return an error message when a proof-bearing claim cannot satisfy its requested authority surface.
- require_
runtime_ claim_ with_ policy - Return an error when policy or proof/runtime ceilings cannot satisfy the requested authority surface.
- runtime_
claim_ preflight - Preflight a proof-bearing runtime claim before a command emits, exports, or persists an authority-bearing result.
- runtime_
claim_ preflight_ with_ policy - Preflight a proof-bearing runtime claim and include an ADR 0026 policy decision in the ceiling computation.