Core data types for the Web Compiler’s compiled schema output.
Structs
- Action
Param - A parameter for a compiled action.
- Compiled
Action - A compiled HTTP action (method) on a model.
- Compiled
Schema - A fully compiled schema for a single website domain.
- Data
Model - A typed data model inferred from structured data on the site.
- Generated
File - A single generated file.
- Generated
Files - Files generated by the code generator.
- Model
Field - A single field within a data model.
- Model
Relationship - A relationship between two models.
- Schema
Stats - Compilation statistics.
- Traversal
Hint - Hint for how to traverse a relationship in the graph.
Enums
- Cardinality
- Cardinality of a model relationship.
- Field
Source - Source of a discovered field.
- Field
Type - Inferred type for a model field.