REFRESH handler — re-render nodes and update the map.
Structs
- Refresh
Request - Parameters for a refresh operation.
- Refresh
Result - Result of a refresh operation.
Functions
- detect_
changes - Compare old and new features to detect changes.
- feature_
hash - Compute a content hash for a feature vector (to detect changes).
- select_
nodes_ to_ refresh - Determine which nodes to refresh based on the request parameters.