WATCH handler — monitor nodes for changes over time.
When watching nodes that have JSON-LD data, prefers HTTP GET + structured data comparison instead of browser rendering. Only falls back to browser for nodes without structured data.
Structs
- Watch
Delta - A change detected during watching.
- Watch
Request - Parameters for a watch operation.
Functions
- compute_
delta - Compare feature vectors and produce a delta if changed.
- fetch_
node_ features_ http - Fetch updated features for a node via HTTP (no browser).
- select_
watch_ nodes - Select which nodes to watch based on the request.