Pool manager for browser rendering contexts.
Manages a pool of browser contexts, controlling concurrency and reusing contexts when possible.
Structs
- Context
Handle - Handle to a borrowed browser context from the pool.
- Pool
Manager - Manages a pool of browser contexts with concurrency limits.